@@ -1,7 +1,7 @@
-/*	$NetBSD: ftpd.c,v 1.122 2001/03/16 20:42:13 christos Exp $	*/
+/*	$NetBSD: ftpd.c,v 1.125 2001/04/25 01:46:26 lukem Exp $	*/
 
 /*
- * Copyright (c) 1997-2000 The NetBSD Foundation, Inc.
+ * Copyright (c) 1997-2001 The NetBSD Foundation, Inc.
  * All rights reserved.
  *
  * This code is derived from software contributed to The NetBSD Foundation
@@ -225,6 +225,7 @@ main(int argc, char *argv[])
 	hostname[0] = '\0';
 	homedir[0] = '\0';
 	gidcount = 0;
+	is_oob = 0;
 	version = FTPD_VERSION;
 
 	/*
@@ -482,8 +483,7 @@ main(int argc, char *argv[])
 		reply(220, "%s FTP server (%s) ready.", hostname, version);
 
 	(void) setjmp(errcatch);
-	for (;;)
-		(void) yyparse();
+	ftp_loop();
 	/* NOTREACHED */
 }
 
@@ -2168,6 +2168,33 @@ dologout(int status)
 	_exit(status);
 }
 
+void
+abor(void)
+{
+
+	tmpline[0] = '\0';
+	is_oob = 0;
+	reply(426, "Transfer aborted. Data connection closed.");
+	reply(226, "Abort successful");
+	longjmp(urgcatch, 1);
+}
+
+void
+statxfer(void)
+{
+
+	tmpline[0] = '\0';
+	is_oob = 0;
+	if (file_size != (off_t) -1)
+		reply(213,
+		    "Status: " LLF " of " LLF " byte%s transferred",
+		    (LLT)byte_count, (LLT)file_size,
+		    PLURAL(byte_count));
+	else
+		reply(213, "Status: " LLF " byte%s transferred",
+		    (LLT)byte_count, PLURAL(byte_count));
+}
+
 static void
 myoob(int signo)
 {
@@ -2177,27 +2204,13 @@ myoob(int signo)
 	if (!transflag)
 		return;
 	cp = tmpline;
-	if (getline(cp, 7, stdin) == NULL) {
+	if (getline(cp, sizeof(tmpline), stdin) == NULL) {
 		reply(221, "You could at least say goodbye.");
 		dologout(0);
 	}
-	if (strcasecmp(cp, "ABOR\r\n") == 0) {
-		tmpline[0] = '\0';
-		reply(426, "Transfer aborted. Data connection closed.");
-		reply(226, "Abort successful");
-		longjmp(urgcatch, 1);
-	}
-	if (strcasecmp(cp, "STAT\r\n") == 0) {
-		tmpline[0] = '\0';
-		if (file_size != (off_t) -1)
-			reply(213,
-			    "Status: " LLF " of " LLF " byte%s transferred",
-			    (LLT)byte_count, (LLT)file_size,
-			    PLURAL(byte_count));
-		else
-			reply(213, "Status: " LLF " byte%s transferred",
-			    (LLT)byte_count, PLURAL(byte_count));
-	}
+	is_oob = 1;
+	ftp_handle_line(cp);
+	is_oob = 0;
 }
 
 static int
@@ -2685,7 +2698,6 @@ send_file_list(const char *whichf)
 			}
 			cprintf(dout, "%s%s\n", dirname,
 			    type == TYPE_A ? "\r" : "");
-			byte_count += strlen(dirname) + 1;
 			continue;
 		} else if (!S_ISDIR(st.st_mode))
 			continue;
@@ -2731,7 +2743,6 @@ send_file_list(const char *whichf)
 					p = &nbuf[2];
 				cprintf(dout, "%s%s\n", p,
 				    type == TYPE_A ? "\r" : "");
-				byte_count += strlen(nbuf) + 1;
 			}
 		}
 		(void) closedir(dirp);
